@@ -264,9 +264,8 @@ def AddLROMaximumTimeout(parser):
 def AddVersion(parser):
   parser.add_argument(
       '--version',
-      hidden=True,
       help="""
-      The target cluster version. For example: "1.5.0".
+      Target cluster version. For example: "1.5.0".
       """
   )
 
@@ -274,10 +273,9 @@ def AddVersion(parser):
 def AddReleaseChannel(parser):
   parser.add_argument(
       '--release-channel',
-      hidden=True,
       default='RELEASE_CHANNEL_UNSPECIFIED',
       help="""
-      The release channel a cluster is subscribed to. It supports two values,
+      Release channel a cluster is subscribed to. It supports two values,
       NONE and REGULAR. NONE is used to opt out of any release channel. Clusters
       subscribed to the REGULAR channel will be automatically upgraded to
       versions that are considered GA quality, and cannot be manually upgraded.
