@@ -21,9 +21,7 @@ from __future__ import unicode_literals
 import os
 
 from googlecloudsdk.command_lib.storage import errors
-from googlecloudsdk.command_lib.storage import gzip_util
 from googlecloudsdk.command_lib.storage import manifest_util
-from googlecloudsdk.command_lib.storage import storage_url
 from googlecloudsdk.command_lib.storage import tracker_file_util
 from googlecloudsdk.command_lib.storage.tasks import compose_objects_task
 from googlecloudsdk.command_lib.storage.tasks import task
@@ -41,11 +39,11 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
       expected_component_count,
       source_resource,
       destination_resource,
-      source_path,
       delete_source=False,
       posix_to_set=None,
       print_created_message=False,
       random_prefix='',
+      temporary_paths_to_clean_up=None,
       user_request_args=None,
   ):
     """Initializes task.
@@ -56,8 +54,6 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
         uploaded file.
       destination_resource (resource_reference.UnknownResource): Metadata for
         the final composite object.
-      source_path (str): Path to file to upload. May be the original or a
-        transformed temporary file.
       delete_source (bool): If copy completes successfully, delete the source
         object afterwards.
       posix_to_set (PosixAttributes|None): POSIX info set as custom cloud
@@ -66,6 +62,9 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
       print_created_message (bool): Print a message containing the versioned URL
         of the copy result.
       random_prefix (str): Random id added to component names.
+      temporary_paths_to_clean_up (str): Paths to remove after the composite
+        upload completes. This may include a temporary gzipped version of the
+        source, or symlink placeholders.
       user_request_args (UserRequestArgs|None): Values for RequestConfig.
     """
     super(FinalizeCompositeUploadTask, self).__init__(
@@ -75,10 +74,10 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
         user_request_args=user_request_args,
     )
     self._expected_component_count = expected_component_count
-    self._source_path = source_path
     self._delete_source = delete_source
     self._print_created_message = print_created_message
     self._random_prefix = random_prefix
+    self._temporary_paths_to_clean_up = temporary_paths_to_clean_up
 
   def execute(self, task_status_queue=None):
     uploaded_components = [
@@ -90,10 +89,12 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
     if len(uploaded_components) != self._expected_component_count:
       raise errors.Error(
           'Temporary components were not uploaded correctly.'
-          ' Please retry this upload.')
+          ' Please retry this upload.'
+      )
 
     uploaded_objects = [
-        component.object_resource for component in sorted(
+        component.object_resource
+        for component in sorted(
             uploaded_components,
             key=lambda component: component.component_number)
     ]
@@ -106,10 +107,12 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
         user_request_args=self._user_request_args,
     )
     compose_task_output = compose_task.execute(
-        task_status_queue=task_status_queue)
+        task_status_queue=task_status_queue
+    )
 
     result_resource = task_util.get_first_matching_message_payload(
-        compose_task_output.messages, task.Topic.CREATED_RESOURCE)
+        compose_task_output.messages, task.Topic.CREATED_RESOURCE
+    )
     if result_resource:
       if self._print_created_message:
         log.status.Print('Created: {}'.format(result_resource.storage_url))
@@ -118,42 +121,46 @@ class FinalizeCompositeUploadTask(copy_util.CopyTaskWithExitHandler):
             task_status_queue,
             self._source_resource,
             self._destination_resource,
-            md5_hash=result_resource.md5_hash)
+            md5_hash=result_resource.md5_hash,
+        )
 
     # After a successful compose call, we consider the upload complete and can
     # delete tracker files.
     tracker_file_path = tracker_file_util.get_tracker_file_path(
         self._destination_resource.storage_url,
         tracker_file_util.TrackerFileType.PARALLEL_UPLOAD,
-        source_url=self._source_resource)
+        source_url=self._source_resource,
+    )
     tracker_file_util.delete_tracker_file(tracker_file_path)
 
-    if gzip_util.should_gzip_locally(
-        getattr(self._user_request_args, 'gzip_settings', None),
-        self._source_path) and self._source_path.endswith(
-            storage_url.TEMPORARY_FILE_SUFFIX):
-      # Delete temporary gzipped version of source file.
-      os.remove(self._source_path)
+    for path in self._temporary_paths_to_clean_up or []:
+      os.remove(path)
     if self._delete_source:
       # Delete original source file.
       os.remove(self._source_resource.storage_url.object_name)
 
     return task.Output(
-        additional_task_iterators=[[
-            delete_temporary_components_task.DeleteTemporaryComponentsTask(
-                self._source_resource,
-                self._destination_resource,
-                self._random_prefix,
-            )
-        ]],
-        messages=None)
+        additional_task_iterators=[
+            [
+                delete_temporary_components_task.DeleteTemporaryComponentsTask(
+                    self._source_resource,
+                    self._destination_resource,
+                    self._random_prefix,
+                )
+            ]
+        ],
+        messages=None,
+    )
 
   def __eq__(self, other):
     if not isinstance(other, type(self)):
       return NotImplemented
-    return (self._expected_component_count == other._expected_component_count
-            and self._source_resource == other._source_resource and
-            self._destination_resource == other._destination_resource and
-            self._source_path == other._source_path and
-            self._random_prefix == other._random_prefix and
-            self._user_request_args == other._user_request_args)
+    return (
+        self._expected_component_count == other._expected_component_count
+        and self._source_resource == other._source_resource
+        and self._destination_resource == other._destination_resource
+        and self._random_prefix == other._random_prefix
+        and self._temporary_paths_to_clean_up
+        == other._temporary_paths_to_clean_up
+        and self._user_request_args == other._user_request_args
+    )
