@@ -22,9 +22,8 @@ from __future__ import unicode_literals
 import abc
 import collections
 import fnmatch
-import glob
-import itertools
 import os
+import pathlib
 import re
 
 from googlecloudsdk.api_lib.storage import api_factory
@@ -36,7 +35,6 @@ from googlecloudsdk.command_lib.storage import storage_url
 from googlecloudsdk.command_lib.storage.resources import resource_reference
 from googlecloudsdk.core import log
 from googlecloudsdk.core.util import debug_output
-
 import six
 
 
@@ -44,6 +42,12 @@ _FILES_ONLY_ERROR_FORMAT = 'Expected files but got stream: {}'
 COMPRESS_WILDCARDS_REGEX = re.compile(r'\*{3,}')
 WILDCARD_REGEX = re.compile(r'[*?\[\]]')
 
+_RELATIVE_PATH_SYMBOLS = frozenset(['.', '.' + os.sep, '..', '..' + os.sep])
+
+
+def _is_hidden(path):
+  return path.rpartition(os.sep)[2].startswith('.')
+
 
 def contains_wildcard(url_string):
   """Checks whether url_string contains a wildcard.
@@ -203,17 +207,9 @@ class FileWildcardIterator(WildcardIterator):
       )
     self._path = self._url.object_name
     self._recurse = '**' in self._path
-    self._include_hidden_files = self._recurse or force_include_hidden_files
-    # TODO(b/284493911): This can be removed with better hidden file handling.
-    if self._include_hidden_files and re.search(
-        r'{sep}\.[^{sep}]+'.format(sep=re.escape(os.sep)), self._path
-    ):
-      # Example matches: `\.hidden-file.txt` & `/.**hidden-dir/file.txt`
-      # Does not match: `/./`
-      log.warning(
-          'Wildcard input pattern may match hidden files, which could cause'
-          ' duplicate matches to the hidden files matched by other flags.'
-      )
+    self._include_hidden_files = (
+        self._recurse or force_include_hidden_files or _is_hidden(self._path)
+    )
 
   def __iter__(self):
     # Files named '-' will not be copied, as that string makes is_stdio true.
@@ -223,27 +219,44 @@ class FileWildcardIterator(WildcardIterator):
             _FILES_ONLY_ERROR_FORMAT.format(self._url.object_name)
         )
       yield resource_reference.FileObjectResource(self._url)
+      return
 
-    normal_file_iterator = glob.iglob(self._path, recursive=self._recurse)
-    # TODO(b/284493911): Current hidden file handling misses some cases.
-    if self._include_hidden_files:
-      # Python 3.11 supports a hidden file kwarg, so if we drop all previous
-      # versions, we can stop this pattern nonsense.
-      if self._recurse:
-        # `**` requires `recursive=True` to work.
-        # Ex: /some/path -> some/path/**/.* (also matches `some/path/.*`)
-        hidden_file_glob_pattern = os.path.join(self._path, '**', '.*')
-      else:
-        # Should error in __init__ for non-compliant URLs.
-        # Ex: /some/path/** -> some/path/.*
-        hidden_file_glob_pattern = self._path.rstrip('*') + '.*'
-      hidden_file_iterator = glob.iglob(
-          hidden_file_glob_pattern, recursive=True
-      )
+    if self._path in _RELATIVE_PATH_SYMBOLS:
+      # Otherwise copies involving relative paths raise pathlib errors:
+      # b/289221450.
+      yield resource_reference.FileDirectoryResource(self._url)
+      return
+
+    pathlib_path = pathlib.Path(self._path).expanduser()
+    if pathlib_path.root:
+      # It's a path that starts with a root. Create the glob pattern relative
+      # to the root dir. Ex: /usr/a/b/c => (usr, a, b, c)
+      path_components_relative_to_root = list(pathlib_path.parts[1:])
+      path_relative_to_root = os.path.join(*path_components_relative_to_root)
+      root = pathlib_path.anchor
     else:
-      hidden_file_iterator = []
-    for path in itertools.chain(normal_file_iterator, hidden_file_iterator):
-      if self._exclude_patterns and self._exclude_patterns.match(path):
+      root = '.'
+      path_relative_to_root = self._path
+    if path_relative_to_root.endswith('**'):
+      path_relative_to_root = os.path.join(path_relative_to_root, '*')
+
+    # Pathlib removes leading './' from paths, but the upload path completion
+    # assumes that the expanded path contains './' if the user's path does.
+    current_working_directory_prefix = '.' + os.sep
+    if self._path.startswith(current_working_directory_prefix):
+      path_prefix = current_working_directory_prefix
+    else:
+      path_prefix = ''
+
+    path_iterator = (
+        path_prefix + str(p)
+        for p in pathlib.Path(root).glob(path_relative_to_root)
+    )
+
+    for path in path_iterator:
+      if (self._exclude_patterns and self._exclude_patterns.match(path)) or (
+          not self._include_hidden_files and _is_hidden(path)
+      ):
         continue
       if self._files_only and not os.path.isfile(path):
         if storage_url.is_named_pipe(path):
