@@ -756,6 +756,40 @@ class SpannerGrpcAsyncIOTransport(SpannerTransport):
             )
         return self._stubs['partition_read']
 
+    @property
+    def batch_write(self) -> Callable[
+            [spanner.BatchWriteRequest],
+            Awaitable[spanner.BatchWriteResponse]]:
+        r"""Return a callable for the batch write method over gRPC.
+
+        Batches the supplied mutation groups in a collection
+        of efficient transactions. All mutations in a group are
+        committed atomically. However, mutations across groups
+        can be committed non-atomically in an unspecified order
+        and thus, they must be independent of each other.
+        Partial failure is possible, i.e., some groups may have
+        been committed successfully, while some may have failed.
+        The results of individual batches are streamed into the
+        response as the batches are applied.
+
+        Returns:
+            Callable[[~.BatchWriteRequest],
+                    Awaitable[~.BatchWriteResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'batch_write' not in self._stubs:
+            self._stubs['batch_write'] = self.grpc_channel.unary_stream(
+                '/google.spanner.v1.Spanner/BatchWrite',
+                request_serializer=spanner.BatchWriteRequest.serialize,
+                response_deserializer=spanner.BatchWriteResponse.deserialize,
+            )
+        return self._stubs['batch_write']
+
     def close(self):
         return self.grpc_channel.close()
 
