@@ -18,15 +18,20 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from typing import Optional
+
 from googlecloudsdk.api_lib.container.gkeonprem import bare_metal_node_pools as apis
 from googlecloudsdk.api_lib.container.gkeonprem import operations
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import parser_arguments
+from googlecloudsdk.calliope import parser_extensions
 from googlecloudsdk.command_lib.container.bare_metal import cluster_flags
 from googlecloudsdk.command_lib.container.bare_metal import constants as bare_metal_constants
 from googlecloudsdk.command_lib.container.bare_metal import node_pool_flags
 from googlecloudsdk.command_lib.container.gkeonprem import constants
 from googlecloudsdk.core import log
+from googlecloudsdk.generated_clients.apis.gkeonprem.v1 import gkeonprem_v1_messages as messages
+
 
 _EXAMPLES = """
 To create a node pool named ``my-node-pool'' in a cluster named
@@ -36,8 +41,8 @@ $ {command} my-node-pool --cluster=my-cluster --location=us-west1
 """
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
-class Create(base.CreateCommand):
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class CreateBeta(base.CreateCommand):
   """Create a node pool in an Anthos cluster on bare metal."""
 
   detailed_help = {'EXAMPLES': _EXAMPLES}
@@ -88,3 +93,60 @@ class Create(base.CreateCommand):
                           'node pool in Anthos cluster on bare metal',
                           args.async_)
     return operation_response
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class CreateAlpha(base.CreateCommand):
+  """Create a node pool in an Anthos cluster on bare metal."""
+
+  detailed_help = {'EXAMPLES': _EXAMPLES}
+
+  @staticmethod
+  def Args(parser: parser_arguments.ArgumentInterceptor):
+    """Gathers command line arguments for the create command.
+
+    Args:
+      parser: The argparse parser to add the flag to.
+    """
+    parser.display_info.AddFormat(
+        bare_metal_constants.BARE_METAL_NODE_POOLS_FORMAT)
+    node_pool_flags.AddNodePoolResourceArg(parser, 'to create')
+    cluster_flags.AddValidationOnly(parser)
+    base.ASYNC_FLAG.AddToParser(parser)
+    node_pool_flags.AddNodePoolAnnotations(parser)
+    node_pool_flags.AddNodePoolDisplayName(parser)
+    node_pool_flags.AddNodePoolConfig(parser)
+    node_pool_flags.AddNodePoolVersion(parser)
+
+  def Run(
+      self, args: parser_extensions.Namespace
+  ) -> Optional[messages.Operation]:
+    """Runs the create command.
+
+    Args:
+      args: The arguments received from command line.
+
+    Returns:
+      The return value depends on the command arguments. If `--async` is
+      specified, it returns an operation; otherwise, it returns the created
+      resource. If `--validate-only` is specified, it returns None or any
+      possible error.
+    """
+    node_pool_ref = args.CONCEPTS.node_pool.Parse()
+    client = apis.NodePoolsClient()
+    operation = client.Create(args)
+
+    if args.async_ and not args.IsSpecified('format'):
+      args.format = constants.OPERATIONS_FORMAT
+
+    if args.async_:
+      return operation
+
+    operation_client = operations.OperationsClient()
+    operation_response = operation_client.Wait(operation)
+
+    if not args.validate_only:
+      log.CreatedResource(node_pool_ref,
+                          'node pool in Anthos cluster on bare metal',
+                          args.async_)
+    return operation_response
