@@ -19,6 +19,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
+from googlecloudsdk.calliope import parser_arguments
 from googlecloudsdk.command_lib.projects import util
 from googlecloudsdk.core import log
 
@@ -28,5 +29,5 @@ class Operations(base.Group):
   """Manage Anthos on VMware long running operations."""
 
   @staticmethod
-  def Args(parser):
+  def Args(parser: parser_arguments.ArgumentInterceptor):
     pass
