@@ -193,8 +193,9 @@ class Update(base.Command):
           suppress_output=args.async_,
       ) as tracker:
         service = client.ReleaseService(
-            service_ref, changes, tracker, asyn=args.async_, prefetch=service
-        )
+            service_ref, changes, tracker, asyn=args.async_, prefetch=service,
+            generate_name=flags.FlagIsExplicitlySet(args, 'revision_suffix'),
+            )
 
       if args.async_:
         pretty_print.Success(
